/*
 * Copyright 2001-2004 (C) MetaStuff, Ltd. All Rights Reserved.
 * 
 * This software is open source. 
 * See the bottom of this file for the licence.
 * 
 * $Id: ProcessingInstruction.java,v 1.8 2004/06/25 12:34:47 maartenc Exp $
 */

package org.dom4j;

import java.util.Map;
    
/** <p><code>ProcessingInstruction</code> defines an XML processing instruction.
  * The {@link Node#getName} method will return the target of the PI and the
  * {@link Node#getText} method will return the data from all of the instructions.
  * </p>
  *
  * @author <a href="mailto:james.strachan@metastuff.com">James Strachan</a>
  * @version $Revision: 1.8 $
  */
public interface ProcessingInstruction extends Node {

    /** This method is the equivalent to the {@link #getName} 
      * method. It is added for clarity.
      *
      * @return the target of this PI
      */
    public String getTarget();
    
    /** This method is the equivalent to the {@link #setName} 
      * method. It is added for clarity.
      */
    public void setTarget(String target);

    /** @return the text for all the data associated with
      * the processing instruction
      */
    public String getText();
    
    /** <p>Returns the value of a specific name in the PI.</p>
      *
      * @param name is the name of the attribute to lookup.
      * @return the value of the named attribute
      */
    public String getValue(String name);
    
    /** @return the values for this processing instruction as 
      * a Map
      */
    public Map getValues();

    public void setValue(String name, String value);    
    public void setValues(Map data);
    public boolean removeValue(String name);
    
}






/*
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "DOM4J" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of MetaStuff, Ltd.  For written permission,
 *    please contact dom4j-info@metastuff.com.
 *
 * 4. Products derived from this Software may not be called "DOM4J"
 *    nor may "DOM4J" appear in their names without prior written
 *    permission of MetaStuff, Ltd. DOM4J is a registered
 *    trademark of MetaStuff, Ltd.
 *
 * 5. Due credit should be given to the DOM4J Project - 
 *    http://www.dom4j.org
 *
 * THIS SOFTWARE IS PROVIDED BY METASTUFF, LTD. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * METASTUFF, LTD. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 2001-2004 (C) MetaStuff, Ltd. All Rights Reserved.
 *
 * $Id: ProcessingInstruction.java,v 1.8 2004/06/25 12:34:47 maartenc Exp $
 */
